/**
 * \file reed-muller.h
 *
 * \brief Mini librairy to manipulate binary Reed-Muller code parameters,
 *        for code based steganography.
 *
 * \author Morgan Barbier <morgan.barbier@ensicaen.fr>
 *
 * \version 1.0
 *
 * \date 2014-10-15
 *
 * \copyright This file is part of stegocurve.

 stegocurve is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 stegocurve is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with stegocurve. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __REED_MULLER_H__
#define __REED_MULLER_H__

#include "codes/code.h"
#include <stdio.h>

/**
 * \fn void init_RM_code(Code *C, const uint parameter);
 *
 * \brief Initialize C as a binary Reed-Muller code of 
 *        parameter. This initialization is for the worst case.
 *
 * \warning This is ONLY for the worst case.
 *          These parameters has found with Magma.
 *
 * \param[out] C the code to initialize
 * \param[in] parameter the parameter of the binary Reed-Muller code.
 *            It can take as for value 3, 4, 5, 6 and 7.
 */
void init_RM_code(Code *C, const uint parameter);
/**
 * \fn void init_RM_codes(Code *C, const uint start, const uint nb);
 *
 * \brief Initialize C as an array, of size nb, of binary Reed-Muller codes where
 *        the smallest parameter is start. This initialization is for the worst case.
 *
 * \warning This is ONLY for the worst case.
 *          These parameters has found with Magma.
 *
 * \param[out] C array of codes to initialize
 * \param[in] start is the smallest parameter
 * \param[in] nb is the size of the array
 */
void init_RM_codes(Code *C, const uint start, const uint nb);
/**
 * \fn void RM_codes_WC(const char* filename);
 *
 * \brief Create or erase the file filename with the data of the
 *        binary Reed-Muller codes for the worst case.
 *
 * \param[in] filename the name of the output file
 */
void RM_codes_WC(const char* filename);

#endif /* __REED_MULLER_H__ */
