/**
 *This file is part of stegocurve.

 stegocurve is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 stegocurve is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with stegocurve. If not, see <http://www.gnu.org/licenses/>.
 */

#include "codes/code.h"

void malloc_codes(Code **C, const uint nb)
{
  *C = malloc(nb * sizeof(Code));
  assert(*C != NULL);
}

void free_codes(Code **C)
{
  free(*C);
  *C = NULL;
}


void init_code_WC(Code *C, const uint n, const uint k, const uint cr)
{
  uint codim = n - k;

  C->n  = n;
  C->k  = k;
  C->cr = cr;

  C->rp = (double)codim / (double)n;
  C->ee = (double)codim / (double)cr;

  C->a_cr = 0;
  C->a_ee = 0;
}


void init_code_AC(Code *C, const uint n, const uint k, const double a_cr)
{
  uint codim = n - k;

  C->n    = n;
  C->k    = k;
  C->a_cr = a_cr;

  C->rp   = (double)codim / (double)n;
  C->a_ee = (double)codim / (double)a_cr;

  C->cr = 0;
  C->ee = 0;
}


void update_code_WC(Code *C, const uint cr)
{
  C->cr = cr;
  C->ee = (double)(C->n-C->k) / (double)cr;
}

void update_code_AC(Code *C, const double a_cr)
{
  C->a_cr = a_cr;
  C->a_ee = (double)(C->n-C->k) / (double)a_cr;
}


void init_generic_codes(Code *C,
			const uint start,
			const uint nb,
			void (*init_fct)(Code*, const uint))
{
  uint i = 0;

  for(; i<nb; ++i)
    {
      (*init_fct)(C + i, start + i);
    }
}



uint get_len(const Code *C)
{
  return(C->n);
}

uint get_dim(const Code *C)
{
  return(C->k);
}

uint get_CR(const Code *C)
{
  return(C->cr);
}

uint get_codim(const Code *C)
{
  return(C->n - C->k);
}

double get_EE(const Code *C)
{
  return(C->ee);
}

double get_RP(const Code *C)
{
  return(C->rp);
}

double get_ACR(const Code *C)
{
  return(C->a_cr);
}

double get_AEE(const Code *C)
{
  return(C->a_ee);
}



void display_datum_WC(FILE *out, const Code *C)
{
  fprintf(out, "%f\t%f\n", C->rp, C->ee);
}

void display_datum_AC(FILE *out, const Code *C)
{
  fprintf(out, "%f\t%f\n", C->rp, C->a_ee);
}

void display_data_WC(FILE *out, const Code *C, const uint size)
{
  uint i = 0;

  for(;i<size; ++i)
    {
      display_datum_WC(out, C+i);
    }
}

void display_data_AC(FILE *out, const Code *C, const uint size)
{
  uint i = 0;

  for(;i<size; ++i)
    {
      display_datum_AC(out, C+i);
    }
}


void display_code_parameters(FILE *out, const Code *C)
{
  fprintf(out, "[%u, %u]\n", C->n, C->k);
  fprintf(out, "CR\t= %u\nACR\t=%f", C->cr, C->a_cr);
  fprintf(out, "RP\t= %f\nEE\t= %f\nAEE\t= %f\n\n", C->rp, C->ee, C->a_ee);
}


void generic_codes_generic_cases(const char* filename,
				 const uint start,
				 const uint nb,
				 void (*init_fct)(Code*, const uint, const uint),
				 void (*display_fct)(FILE*, const Code*, const uint))
{
  Code *C;
  FILE *out = fopen(filename, "w");
  
  assert(out != NULL);

  malloc_codes(&C, nb);
  (*init_fct)(C, start, nb);
  
  (*display_fct)(out, C, nb);

  free_codes(&C);
  fclose(out);

}

