/**
 *This file is part of stegocurve.

 stegocurve is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 stegocurve is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with stegocurve. If not, see <http://www.gnu.org/licenses/>.
 */

#include "stegocurve.h"
#include <stdio.h>
#include <string.h>




void print_usage(FILE* out)
{
  fprintf(out, "USAGE:\tstegocurve ACTION [OPTION]\n\n");
  fprintf(out, "ACTION:\n");
  fprintf(out, "  generate:\n\tgenerate the data files, the directory where the data file will be written is mandatory.\n");
  fprintf(out, "\tEXAMPLE:\n\t\tstegocurve generate datadirectory\n");

  fprintf(out, "\n\t*********\n\n");

  fprintf(out, "  gnuplot:\n\tplot the data files with gnuplot. The options are mandatatory.\n");
  fprintf(out, "\tEXAMPLE:\n\t\tstegocurve plot datafile1 name1 ... datafileN nameN outputname\n");

  fprintf(out, "  pgfplots:\n\tplot the data files with Latex with packages tikz/pgfplots. The options are mandatatory.\n");
  fprintf(out, "\tEXAMPLE:\n\t\tstegocurve plot datafile1 name1 ... datafileN nameN outputname\n");

  fprintf(out, "  tikz:\n\tplot the data files with Latex with package tikz. The options are mandatatory.\n");
  fprintf(out, "\tEXAMPLE:\n\t\tstegocurve plot datafile1 name1 ... datafileN nameN outputname\n");

  fprintf(out, "\n\t*********\n\n");
  
  fprintf(out, "  path to config file: the config will be used to define the behavior of stegocurve.\n");
  fprintf(out, "\tEXAMPLE:\n\t\tstegocurve stegocurve.cfg\n");
}


#ifdef __linux__
int main(const int argc, const char *argv[])
{
  Plotter P;
  stegocurve_args args;
  stegocurve_action action;

  if (argc < 2)
    {
      print_usage(stderr);
      return(EXIT_FAILURE);
    }
  else if(! strncmp(argv[1], "tikz", 5))
    {
      if (argc%2 == 0)
	{
	  print_usage(stderr);
	  return(EXIT_FAILURE);
	}

      stegocurve_args_init(&args, argc - 3, argv + 2);
      plotter_tikz_pure_init(&P,
			     argv[argc-1],
			     &args);

      plotter_run(&P);
      plotter_free(&P);
      stegocurve_args_free(&args);
    }
  else if(! strncmp(argv[1], "gnuplot", 8))
    {
      if (argc%2 == 0)
	{
	  print_usage(stderr);
	  return(EXIT_FAILURE);
	}

      stegocurve_args_init(&args, argc - 3, argv + 2);
      plotter_gnuplot_init(&P,
			   GNUPLOT_FILE,
			   argv[argc-1],
			   &args);

      plotter_run(&P);
      plotter_free(&P);
      stegocurve_args_free(&args);
    }
  else if(! strncmp(argv[1], "pgfplots", 9))
    {
      if (argc%2 == 0)
	{
	  print_usage(stderr);
	  return(EXIT_FAILURE);
	}
      
      stegocurve_args_init(&args, argc - 3, argv + 2);
      plotter_pgfplots_init(&P,
			    argv[argc-1],
			    &args);

      plotter_run(&P);
      plotter_free(&P);
      stegocurve_args_free(&args);
    }
  else if(! strncmp(argv[1], "generate", 9))
    {
      if (argc != 3)
	{
	  print_usage(stderr);
      	  return(EXIT_FAILURE);
	}

      generate_all(argv[2]);
    }
  else
    {
      stegocurve_action_init(&action);
      stegocurve_read_config_file(&action, argv[1]);

      stegocurve_action_do(&action);

      stegocurve_action_free(&action);
    }
  return(EXIT_SUCCESS);
}
#endif /* __linux__ */



#ifdef __WIN32__
int main(void)
{
  stegocurve_action action;

  stegocurve_action_init(&action);
  stegocurve_read_config_file(&action, "./stegocurve.cfg");
  
  stegocurve_action_print(&action);
  stegocurve_action_do(&action);
  
  stegocurve_action_free(&action);
  return(EXIT_SUCCESS);
}
#endif /* __WIN32__ */

