#include "plotters/plotter_gnuplot.h"



void plotter_gnuplot_pre_proc(Plotter *P)
{
  fprintf(P->Plotter_file, "set terminal postscript eps color \"Times-Roman\" 16\n");
  fprintf(P->Plotter_file, "set output '%s'\n\n", P->output_filename);

  fprintf(P->Plotter_file, "set title 'Embedding efficiency as a function of relative payload'\n");
  fprintf(P->Plotter_file, "set xlabel 'a : relative payload'\n");
  fprintf(P->Plotter_file, "set ylabel 'e : embedding efficiency'\n\n");

  fprintf(P->Plotter_file, "set yrange [2:12]\n\nplot");
}

void plotter_gnuplot_proc(Plotter *P)
{
  int 
    size = stegocurve_args_get_size(P->data)-1,
    i    = 1;


  fprintf(P->Plotter_file, "     '%s' using 1:2 with line title '%s'", P->data->data[0][0], P->data->data[0][1]);
  if(size==0) 
    {
      fprintf(P->Plotter_file, "\n");
      return;
    }
  else
    {
      fprintf(P->Plotter_file, ",\\\n");
    }

  for(; i<size; ++i)
    {
      fprintf(P->Plotter_file, "     '%s' using 1:2 with linespoint title '%s',\\\n", P->data->data[i][0], P->data->data[i][1]);
    }
  fprintf(P->Plotter_file, "     '%s' using 1:2 with linespoint title '%s'\n", P->data->data[size][0], P->data->data[size][1]);
}

void plotter_gnuplot_post_proc(Plotter *P)
{
  fclose(P->Plotter_file);
  P->Plotter_file = NULL;
  
#ifdef __linux__
  run_and_wait(2, GNUPLOT_COMMAND, GNUPLOT_FILE);
  run_and_wait(2, EPS_VIEWER, P->output_filename);
#endif /* __linux__ */
}


void plotter_gnuplot_init(Plotter *P, const char* Plotter_filename, const char* output, const stegocurve_args *data)
{
  char *output_filename;
  size_t size = strlen(output);

  if((output_filename = malloc((size + 5) * sizeof(char))) == NULL)
    {
      fprintf(stderr, "MEMORY ERROR: plotter_gnuplot_init() Impossible allocation.\n");
      return;
    }
  
  memcpy(output_filename, output, size);
  output_filename[size] = '\0';

  strncat(output_filename, ".eps", 4);

  plotter_init(P,
	       plotter_gnuplot_pre_proc,
	       plotter_gnuplot_proc,
	       plotter_gnuplot_post_proc,
	       Plotter_filename,
	       output_filename,
	       data);

  free(output_filename);
}
