#include "plotters/plotter_pgfplots.h"



void plotter_pgfplots_pre_proc(Plotter *P)
{
  fprintf(P->Plotter_file,"\
\\documentclass{article}\n\n\
\\usepackage{tikz}\n\
\\usepackage{pgfplots}\n\n\
\\title{Efficiency comparison for code based steganography}\n\
\\author{stegocurve}\n\n\
\\begin{document}\n\
\\maketitle\n\n");

  fprintf(P->Plotter_file,
	  "\\begin{figure}[ht]\n\
\\centering\n");

  fprintf(P->Plotter_file,"\n\
    \\begin{tikzpicture}\n\
    \\begin{axis}[%% Title and labels\n\
        title=Embedding efficiency as a function of relative payload,\n\
        xlabel={$\\alpha$: relative payload},\n\
        ylabel={$e$: embedding efficiency},\n\
        %% window\n\
        ymin=2,\n\
        ymax=12,\n\
        xmin=0,\n\
        xmax=1,\n\
        width=11cm,\n");
}

void plotter_pgfplots_proc(Plotter *P)
{
  uint 
    size = stegocurve_args_get_size(P->data),
    i    = 0;

  fprintf(P->Plotter_file,"\
        %% captions\n\
        legend entries={\n");

  for(; i<size; ++i)
    {
      fprintf(P->Plotter_file,"\
          %s,\n",P->data->data[i][1]);
    }

  fprintf(P->Plotter_file,"\
        },\n\
      ]\n\n\
      %% plot curves\n\
      \\addplot[red] table{%s};\n",P->data->data[0][0]);
  for(i=1; i<size; ++i)
    {
      fprintf(P->Plotter_file,"\
      \\addplot table{%s};\n", P->data->data[i][0]);
    }
  
  fprintf(P->Plotter_file,"\
    \\end{axis}\n\n\
  \\end{tikzpicture}\n\
  \\caption{\\label{fig:stegocurve_pgfplots}\n\
  Curve obtained by stegocurve and the plotter pgfplots}\n\
\\end{figure}\n\
\\end{document}\n");

}

void plotter_pgfplots_post_proc(Plotter *P)
{
  fclose(P->Plotter_file);
  P->Plotter_file = NULL;

#ifdef __linux__
  printf("PLOTTER FILENAME : '%s'\n", P->Plotter_filename);
  printf("PLOTTER OUTPUT   : '%s'\n", P->output_filename);
  run_and_wait(2, LATEX_COMPILER, P->Plotter_filename);
  run_and_wait(2, PDF_VIEWER, P->output_filename);
#endif /* __linux__ */
}


void plotter_pgfplots_init(Plotter *P, const char* Plotter_filename, const stegocurve_args *data)
{
  char 
    *tex_file,
    *pdf_file;

  size_t size = strlen(Plotter_filename);

  tex_file = malloc(5 + size * sizeof(char));
  pdf_file = malloc(5 + size * sizeof(char));

  memcpy(tex_file, Plotter_filename, size);
  memcpy(pdf_file, Plotter_filename, size);
  tex_file[size] = '\0';
  pdf_file[size] = '\0';

  strcat(tex_file, ".tex");
  strcat(pdf_file, ".pdf");

  plotter_init(P,
	       plotter_pgfplots_pre_proc,
	       plotter_pgfplots_proc,
	       plotter_pgfplots_post_proc,
	       tex_file,
	       pdf_file,
	       data);

  free(pdf_file);
  free(tex_file);
}
